diff --git a/sound/usb/mixer_quirks.c b/sound/usb/mixer_quirks.c
index 12125ca..2ba4a28 100644
--- a/sound/usb/mixer_quirks.c
+++ b/sound/usb/mixer_quirks.c
@@ -925,6 +925,52 @@ static int snd_ftu_create_mixer(struct usb_mixer_interface *mixer)
 }
 
 
+/* Try to create mixer controls for M-Audio C400 */
+static int snd_c400_create_vol_ctls(struct usb_mixer_interface *mixer)
+{
+	char name[64];
+	unsigned int control, cmask;
+	int in, out, err;
+
+	const unsigned int id = 0x40;
+	const int val_type = USB_MIXER_S16;
+	const control = 1;
+
+	for (in = 0; in < 10; in++) {
+		for (out = 0; out < 6; out++) {
+			/* Give it a name */
+			if(in < 6) {
+				snprintf(name, sizeof(name),
+					"DIn%d - Out%d Playback Volume",
+					in + 1, out + 1);
+			} else {
+				snprintf(name, sizeof(name),
+					"AIn%d - Out%d Playback Volume",
+					in - 6, out + 1);				
+			}
+			/* Create as many controls as possible a.t.m. */
+			if (in * 6 + out < MAX_CHANNELS {
+				cmask = 1 << (in * 6 + out);
+				err = snd_create_std_mono_ctl(mixer, id, control,
+							cmask, val_type, name,
+							&snd_usb_mixer_vol_tlv);
+				if (err < 0)
+					return err;
+			}
+		}
+	}
+
+	return 0;
+}
+
+static int snd_c400_create_mixer(struct usb_mixer_interface *mixer)
+{
+	int err = 0;
+	err = snd_c400_create_vol_ctls(mixer);
+
+	return err;
+}
+
 /*
  * Create mixer for Electrix Ebox-44
  *
@@ -1025,6 +1071,10 @@ int snd_usb_mixer_apply_create_quirk(struct usb_mixer_interface *mixer)
 		err = snd_ftu_create_mixer(mixer);
 		break;
 
+	case USB_ID(0x0763, 0x2030): /* M-Audio C400 */
+		err = snd_c400_create_mixer(mixer);
+		break;
+
 	case USB_ID(0x0b05, 0x1739):
 	case USB_ID(0x0b05, 0x1743):
 		err = snd_xonar_u1_controls_create(mixer);
